.. _faqs:

Frequently Asked Questions
--------------------------

Can men attend local PyLadies chapter events?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

It’s up to you. Generally, it’s good to hold women-only events as wellas events for both genders (either women and +1 guests, or anyone who wants to attend). Just be aware that the dynamic of the room tends to change when the male:female ratio becomes lopsided.

A good way to hold a mixed-gender event is to partner with a local Python user group.

Be extra-clear in your event description about whether men are allowed/what the rules are -- it will save you a lot of time, and prevent awkward conversations.

Is there anything like PyLadies specifically for men?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

There doesn’t seem to be a burning need for a PyLadies for Men ;) That said, if you’re a man and want to start a similar group, we’ll support you. You can even make PyLadies knock-off t-shirts. One enterprising gent has printed “PyLaddies” shirts, and there is an IRC channel on Freenode, #pygents, for the men who love PyLadies =)

Can I use the PyLadies logo and graphics for any purpose?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Any of the graphics at `https://github.com/pyladies/pyladies-kit <https://github.com/pyladies/pyladies-kit>`_ can be used for your own chapter promotion. Feel free to use them for websites, printed materials, t-shirts, and anything else that benefits your chapter.

Even if you don’t have an official chapter, you can use the graphics for anything women-in-Python related, as long as any funds resulting from your use of the graphics go toward Python gender diversity initiatives.


Can transgender women be PyLadies?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Anyone who considers herself a lady and does Python is a PyLady/Python lady. We support all women, whether female by birth or not.

We encourage you sure to make trans women feel welcome by saying so in your meetup group and event descriptions. Here is an example of a statement you could include:

    PyLadies [city] is welcoming to and respectful of trans women. We
    encourage all women to come out to our meetups.

If the idea of trans people is new to you, you might want to take a look at `this fantastic illustrated book about gender <http://www.thegenderbook.com>`_, `this comic <http://www.roostertailscomic.com/?p=1495>`_, or any of the many other introductions to trans issues on the internet.

Is your goal to segregate by gender?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

No! PyLadies and local PyLadies chapters are about making the Python community explicitly welcoming and accessible to women.

Women who wouldn’t otherwise attend a Python user group meeting often attend local PyLadies chapter events, as a gateway to getting involved with Python programming as a beginner, or getting more involved in the Python community as an intermediate/advanced developer.

What if my question isn’t answered here?
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Ask in IRC #pyladies on `freenode <http://irc.freenode.net>`_ if you must. But feel free to organize your PyLadies chapter however you wish, and make it completely your own. We’re here to help you, not to limit you or control your plans.
